.. start installation

``{{ modname }}`` can be installed from GitHub.

To install with ``pip``:

.. code-block:: bash

	$ python -m pip install git+https://github.com/{{ username }}/{{ repo_name }}

.. end installation
